@@ -149,11 +149,27 @@ int ipkg_cmd_exec(ipkg_cmd_t *cmd, ipkg_conf_t *conf, int argc, const char **arg
 {
 	int result;
 	p_userdata = userdata;
+      
+
 	result = (cmd->fun)(conf, argc, argv);
         if ( result == 0 ) {
            ipkg_message(conf, IPKG_NOTICE, "Successfully terminated.\n");
         } else {
            ipkg_message(conf, IPKG_NOTICE, "An error ocurred, return value: %d.\n", result);
+
+        }
+        if ( error_list ) {
+           reverse_error_list(&error_list);
+
+           ipkg_message(conf, IPKG_NOTICE, "Collected errors:\n");
+           /* Here we print the errors collected and free the list */
+           while (error_list != NULL) {
+                 ipkg_message(conf, IPKG_NOTICE, "%s",error_list->errmsg);
+                 error_list = error_list->next;
+
+           }
+           free_error_list(&error_list);
+
         }
    
 	p_userdata = NULL;
@@ -780,9 +796,9 @@ static int ipkg_remove_cmd(ipkg_conf_t *conf, int argc, char **argv)
 	            ipkg_message(conf, IPKG_ERROR, "Package %s is not installed.\n", pkg->name);
 	            continue;
                }
-               if (pkg->state_want == SW_DEINSTALL) {    // Added the control, so every already removed package could be skipped
-	            ipkg_message(conf, IPKG_ERROR, "Package %s already removed.\n", pkg->name);
-	            continue;
+               if (pkg->state_status == SS_NOT_INSTALLED) {    // Added the control, so every already removed package could be skipped
+	            ipkg_message(conf, IPKG_ERROR, "Package seems to be %s not installed (STATUS = NOT_INSTALLED).\n", pkg->name);
+                    continue;
                }
                ipkg_remove_pkg(conf, pkg_to_remove);
                done = 1;
@@ -1088,11 +1104,11 @@ static int ipkg_what_depends_conflicts_cmd(ipkg_conf_t *conf, enum what_field_ty
 	       if (pkg->state_flag & SF_MARKED) {
 		    /* mark the parent (abstract) package */
 		    pkg_mark_provides(pkg);
-		    ipkg_message(conf, IPKG_ERROR, "  %s\n", pkg->name);
+		    ipkg_message(conf, IPKG_NOTICE, "  %s\n", pkg->name);
 	       }
 	  }
 
-	  ipkg_message(conf, IPKG_ERROR, "What %s root set\n", rel_str);
+	  ipkg_message(conf, IPKG_NOTICE, "What %s root set\n", rel_str);
 	  do {
 	       int j;
 	       changed = 0;
@@ -1119,7 +1135,7 @@ static int ipkg_what_depends_conflicts_cmd(ipkg_conf_t *conf, enum what_field_ty
 				   pkg_mark_provides(pkg);
 				   changed++;
 
-				   ipkg_message(conf, IPKG_ERROR, "    %s", pkg->name);
+				   ipkg_message(conf, IPKG_NOTICE, "    %s", pkg->name);
 				   if (conf->verbosity > 0) {
 					char *ver = pkg_version_str_alloc(pkg); 
 					ipkg_message(conf, IPKG_NOTICE, " %s", ver);
@@ -1140,7 +1156,7 @@ static int ipkg_what_depends_conflicts_cmd(ipkg_conf_t *conf, enum what_field_ty
 					if (!pkg_dependence_satisfiable(conf, possibility))
 					     ipkg_message(conf, IPKG_NOTICE, " unsatisfiable");
 				   }
-				   ipkg_message(conf, IPKG_ERROR, "\n");
+				   ipkg_message(conf, IPKG_NOTICE, "\n");
 				   goto next_package;
 			      }
 			 }
