@@ -154,6 +154,7 @@ pkg_t *pkg_hash_fetch_best_installation_candidate(ipkg_conf_t *conf, abstract_pk
      pkg_t *latest_installed_parent = NULL;
      pkg_t *latest_matching = NULL;
      pkg_t *held_pkg = NULL;
+     pkg_t *good_pkg_by_name = NULL;
 
      if (matching_apkgs == NULL || providers == NULL || 
          apkg == NULL || apkg->provided_by == NULL || (apkg->provided_by->len == 0))
@@ -205,8 +206,7 @@ pkg_t *pkg_hash_fetch_best_installation_candidate(ipkg_conf_t *conf, abstract_pk
 	  }
     
 
-/* Could a package provide more than a package ? */
-	  /* now check for supported architecture and satisfaction of constraint_fcn */
+	  /* now check for supported architecture */
 	  {
 	       int max_count = 0;
 	       int i;
@@ -214,15 +214,10 @@ pkg_t *pkg_hash_fetch_best_installation_candidate(ipkg_conf_t *conf, abstract_pk
 	       /* count packages matching max arch priority and keep track of last one */
 	       for (i = 0; i < vec->len; i++) {
 		    pkg_t *maybe = vec->pkgs[i];
-		    /* only consider the ones that satisfy the constraint */
-		    ipkg_message(conf, IPKG_DEBUG, "  %s arch=%s arch_priority=%d constraint=%d \n",
-				 maybe->name, maybe->architecture,
-				 maybe->arch_priority,
-				 ((constraint_fcn == NULL) || constraint_fcn(maybe, cdata)));
-		    if ((maybe->arch_priority > 0) 
-			&& ((constraint_fcn == NULL) || constraint_fcn(maybe, cdata))) {
+		    ipkg_message(conf, IPKG_DEBUG, "  %s arch=%s arch_priority=%d  \n",
+				 maybe->name, maybe->architecture, maybe->arch_priority);
+		    if (maybe->arch_priority > 0)  {
 			 max_count++;
-
 			 abstract_pkg_vec_insert(matching_apkgs, maybe->parent);
 			 pkg_vec_insert(matching_pkgs, maybe);
 		    }
@@ -235,6 +230,18 @@ pkg_t *pkg_hash_fetch_best_installation_candidate(ipkg_conf_t *conf, abstract_pk
      if (matching_apkgs->len > 1)
 	  abstract_pkg_vec_sort(matching_pkgs, abstract_pkg_name_compare);
 
+/* Here it is usefull, if ( matching_apkgs->len > 1 ), to test if one of this matching packages has the same name of the
+   needed package. In this case, I would return it for install, otherwise I will continue with the procedure */
+
+     for (i = 0; i < matching_pkgs->len; i++) {
+	  pkg_t *matching = matching_pkgs->pkgs[i];
+          if (constraint_fcn(matching, cdata)) {  /* We found it */
+             ipkg_message(conf, IPKG_DEBUG, " Found a valid candidate for the install: %s   \n", matching->name) ;
+             good_pkg_by_name = matching;
+          }
+     }
+
+
      for (i = 0; i < matching_pkgs->len; i++) {
 	  pkg_t *matching = matching_pkgs->pkgs[i];
 	  latest_matching = matching;
@@ -248,14 +255,12 @@ pkg_t *pkg_hash_fetch_best_installation_candidate(ipkg_conf_t *conf, abstract_pk
 	  }
      }
 
-     if (!held_pkg && !latest_installed_parent && matching_apkgs->len > 1 && !quiet) {
+     if (!good_pkg_by_name && !held_pkg && !latest_installed_parent && matching_apkgs->len > 1 && !quiet) {
 	  ipkg_message(conf, IPKG_ERROR, "Package=%s, %d matching providers\n",
 		       apkg->name, matching_apkgs->len);
-	  if (conf->verbosity > 1) {
-	       for (i = 0; i < matching_apkgs->len; i++) {
-		    abstract_pkg_t *matching = matching_apkgs->pkgs[i];
-		    ipkg_message(conf, IPKG_NOTICE, "    %s\n", matching->name);
-	       }
+	  for (i = 0; i < matching_apkgs->len; i++) {
+              abstract_pkg_t *matching = matching_apkgs->pkgs[i];
+              ipkg_message(conf, IPKG_ERROR, "    %s\n", matching->name);
 	  }
 	  ipkg_message(conf, IPKG_ERROR, "Please select one with ipkg install or ipkg flag prefer\n");
      }
@@ -276,6 +281,9 @@ pkg_t *pkg_hash_fetch_best_installation_candidate(ipkg_conf_t *conf, abstract_pk
      abstract_pkg_vec_free(matching_apkgs);
      abstract_pkg_vec_free(providers);
 
+     if (good_pkg_by_name) {   /* We found a good candidate, we will install it */ 
+	  return good_pkg_by_name;
+     }
      if (held_pkg) {
 	  ipkg_message(conf, IPKG_INFO, "  using held package %s\n", held_pkg->name);
 	  return held_pkg;
@@ -302,7 +310,7 @@ static int pkg_name_constraint_fcn(pkg_t *pkg, void *cdata)
      if (strcmp(pkg->name, name) == 0)
 	  return 1;
      else
-	  return 0;
+	  return 0;   /* Pigi */
 }
 
 pkg_t *pkg_hash_fetch_best_installation_candidate_by_name(ipkg_conf_t *conf, const char *name)
@@ -312,7 +320,7 @@ pkg_t *pkg_hash_fetch_best_installation_candidate_by_name(ipkg_conf_t *conf, con
 
      if (!(apkg = abstract_pkg_fetch_by_name(hash, name)))
 	  return NULL;
-
+     
      return pkg_hash_fetch_best_installation_candidate(conf, apkg, pkg_name_constraint_fcn, apkg->name, 0);
 }
 
